@@ -1,4 +1,4 @@
-{-# LANGUAGE TypeSynonymInstances #-}
+{-# LANGUAGE TypeSynonymInstances, ScopedTypeVariables, FlexibleInstances #-}
 {-
 Copyright (C) 2009 John MacFarlane <jgm@berkeley.edu>,
 Anton van Straaten <anton@appsolutions.com>
@@ -35,7 +35,7 @@ import Data.Time (parseTime)
 import System.Locale (defaultTimeLocale)
 import Data.FileStore.Types
 import Network.Gitit.Server
-import Text.Pandoc.CharacterReferences (decodeCharacterReferences)
+import Text.HTML.TagSoup.Entity (lookupEntity)
 
 data PageType = Markdown | RST | LaTeX | HTML | Textile
                 deriving (Read, Show, Eq)
@@ -289,9 +289,17 @@ data Params = Params { pUsername     :: String
                      , pResetCode    :: String
                      }  deriving Show
 
+instance FromReqURI [String] where
+  fromReqURI s = case fromReqURI s of
+                      Just (s' :: String) ->
+                                   case reads s' of
+                                        ((xs,""):_) -> xs
+                                        _           -> Nothing
+                      Nothing             -> Nothing
+
 instance FromData Params where
      fromData = do
-         let look' = liftM decodeCharacterReferences . look
+         let look' = liftM fromEntities . look
          un <- look' "username"       `mplus` return ""
          pw <- look' "password"       `mplus` return ""
          p2 <- look' "password2"      `mplus` return ""
@@ -384,3 +392,16 @@ data WikiState = WikiState {
 type GititServerPart = ServerPartT (ReaderT WikiState IO)
 
 type Handler = GititServerPart Response
+
+-- Unescapes XML entities
+fromEntities :: String -> String
+fromEntities ('&':xs) =
+  case lookupEntity ent of
+        Just c  -> c : fromEntities rest
+        Nothing -> '&' : fromEntities rest
+    where (ent, rest) = case break (==';') xs of
+                             (zs,';':ys) -> (zs,ys)
+                             _           -> ("",xs)
+fromEntities (x:xs) = x : fromEntities xs
+fromEntities [] = []
+
