@@ -61,7 +61,7 @@ customInterwikiMap = [("Hackage", "http://hackage.haskell.org/package/"),
                       ("Hoogle", "http://www.haskell.org/hoogle/?hoogle=")]
 
 -- This mapping is derived from <https://secure.wikimedia.org/wikipedia/meta/wiki/Interwiki_map>
--- as of 11:30 AM, 6 February 2011.
+-- as of 5:18 PM, 6 February 2012.
 wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("AIWiki", "http://www.ifi.unizh.ch/ailab/aiwiki/aiw.cgi?"),
                  ("Acronym", "http://www.acronymfinder.com/af-query.asp?String=exact&Acronym="),
@@ -74,12 +74,13 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("AquariumWiki", "http://www.theaquariumwiki.com/"),
                  ("AspieNetWiki", "http://aspie.mela.de/index.php/"),
                  ("AtmWiki", "http://www.otterstedt.de/wiki/index.php/"),
+                 ("BCNbio", "http://historiapolitica.bcn.cl/resenas_parlamentarias/wiki/"),
                  ("BEMI", "http://bemi.free.fr/vikio/index.php?"),
                  ("BLW", "http://britainloveswikipedia.org/wiki/"),
                  ("BattlestarWiki", "http://en.battlestarwiki.org/wiki/"),
                  ("BenefitsWiki", "http://www.benefitslink.com/cgi-bin/wiki.cgi?"),
                  ("BibleWiki", "http://bible.tmtm.com/wiki/"),
-                 ("BluWiki", "http://www.bluwiki.org/go/"),
+                 ("BluWiki", "http://bluwiki.com/go/"),
                  ("Botwiki", "http://botwiki.sno.cc/wiki/"),
                  ("Boxrec", "http://www.boxrec.com/media/index.php?"),
                  ("BrickWiki", "http://lego.wikia.com/index.php?title="),
@@ -100,6 +101,7 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("Comixpedia", "http://www.comixpedia.org/index.php/"),
                  ("Commons", "http://commons.wikimedia.org/wiki/"),
                  ("CommunityScheme", "http://community.schemewiki.org/?c=s&key="),
+                 ("CommunityWiki", "http://www.communitywiki.org/"),
                  ("CorpKnowPedia", "http://corpknowpedia.org/wiki/index.php/"),
                  ("CrazyHacks", "http://www.crazy-hacks.org/wiki/index.php?title="),
                  ("CreativeCommons", "http://www.creativecommons.org/licenses/"),
@@ -115,11 +117,12 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("DejaNews", "http://www.deja.com/=dnc/getdoc.xp?AN="),
                  ("Delicious", "http://www.delicious.com/tag/"),
                  ("Demokraatia", "http://wiki.demokraatia.ee/index.php/"),
-                 ("Devmo", "http://developer.mozilla.org/en/docs/"),
+                 ("Devmo", "https://developer.mozilla.org/en/docs/"),
                  ("Dict", "http://www.dict.org/bin/Dict?Database=*&Form=Dict1&Strategy=*&Query="),
                  ("Dictionary", "http://www.dict.org/bin/Dict?Database=*&Form=Dict1&Strategy=*&Query="),
                  ("Disinfopedia", "http://www.sourcewatch.org/wiki.phtml?title="),
                  ("DocBook", "http://wiki.docbook.org/topic/"),
+                 ("Donate", "http://donate.wikimedia.org/wiki/"),
                  ("Dreamhost", "http://wiki.dreamhost.com/index.php/"),
                  ("DrumCorpsWiki", "http://www.drumcorpswiki.com/index.php/"),
                  ("ELibre", "http://enciclopedia.us.es/index.php/"),
@@ -130,7 +133,9 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("Encyc", "http://encyc.org/wiki/"),
                  ("EnergieWiki", "http://www.netzwerk-energieberater.de/wiki/index.php/"),
                  ("EoKulturCentro", "http://esperanto.toulouse.free.fr/nova/wikini/wakka.php?wiki="),
+                 ("Etherpad", "http://etherpad.wikimedia.org/"),
                  ("Ethnologue", "http://www.ethnologue.com/show_language.asp?code="),
+                 ("EthnologueFamily", "http://www.ethnologue.com/show_family.asp?subid="),
                  ("EvoWiki", "http://wiki.cotch.net/index.php/"),
                  ("Exotica", "http://www.exotica.org.uk/wiki/"),
                  ("EĉeI", "http://www.ikso.net/cgi-bin/wiki.pl?"),
@@ -160,7 +165,6 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("GlobalVoices", "http://cyber.law.harvard.edu/dyn/globalvoices/wiki/"),
                  ("GlossarWiki", "http://glossar.hs-augsburg.de/"),
                  ("GlossaryWiki", "http://glossary.hs-augsburg.de/"),
-                 ("Golem", "http://golem.linux.it/index.php/"),
                  ("Google", "http://www.google.com/search?q="),
                  ("GoogleDefine", "http://www.google.com/search?q=define:"),
                  ("GoogleGroups", "http://groups.google.com/groups?q="),
@@ -217,6 +221,7 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("Mariowiki", "http://www.mariowiki.com/"),
                  ("MarvelDatabase", "http://www.marveldatabase.com/wiki/index.php/"),
                  ("MeatBall", "http://meatballwiki.org/wiki/"),
+                 ("MediaWikiWiki", "http://www.mediawiki.org/wiki/"),
                  ("MediaZilla", "https://bugzilla.wikimedia.org/"),
                  ("MemoryAlpha", "http://memory-alpha.org/wiki/"),
                  ("MetaWiki", "http://sunir.org/apps/meta.pl?"),
@@ -226,7 +231,7 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("Monstropedia", "http://www.monstropedia.org/?title="),
                  ("MosaPedia", "http://mosapedia.de/wiki/index.php/"),
                  ("MozCom", "http://mozilla.wikia.com/wiki/"),
-                 ("MozillaWiki", "http://wiki.mozilla.org/"),
+                 ("MozillaWiki", "https://wiki.mozilla.org/"),
                  ("MozillaZineKB", "http://kb.mozillazine.org/"),
                  ("MusicBrainz", "http://musicbrainz.org/doc/"),
                  ("NKcells", "http://www.nkcells.info/wiki/index.php/"),
@@ -235,6 +240,7 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("OEIS", "http://oeis.org/"),
                  ("OLPC", "http://wiki.laptop.org/go/"),
                  ("OSI", "http://wiki.tigma.ee/index.php/"),
+                 ("OSMwiki", "http://wiki.openstreetmap.org/wiki/"),
                  ("OTRS", "https://ticket.wikimedia.org/otrs/index.pl?Action=AgentTicketZoom&TicketID="),
                  ("OTRSwiki", "http://otrs-wiki.wikimedia.org/wiki/"),
                  ("OldWikisource", "http://wikisource.org/wiki/"),
@@ -247,11 +253,11 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("Opera7Wiki", "http://operawiki.info/"),
                  ("OrganicDesign", "http://www.organicdesign.co.nz/"),
                  ("OrthodoxWiki", "http://orthodoxwiki.org/"),
-                 ("OurMedia", "http://www.socialtext.net/ourmedia/index.cgi?"),
+                 ("OurMedia", "https://www.socialtext.net/ourmedia/index.cgi?"),
                  ("Outreach", "http://outreach.wikimedia.org/wiki/"),
                  ("OutreachWiki", "http://outreach.wikimedia.org/wiki/"),
                  ("PHWiki", "http://wiki.pocketheaven.com/"),
-                 ("PMEG", "http://www.bertilow.com/pmeg/.php"),
+                 ("PMEG", "http://www.bertilow.com/pmeg/"),
                  ("Panawiki", "http://wiki.alairelibre.net/index.php?title="),
                  ("PatWIKI", "http://gauss.ffii.org/"),
                  ("PerlNet", "http://perl.net.au/wiki/"),
@@ -284,9 +290,10 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("SourceForge", "http://sourceforge.net/"),
                  ("Species", "http://species.wikimedia.org/wiki/"),
                  ("Squeak", "http://wiki.squeak.org/squeak/"),
+                 ("Stewardry", "http://toolserver.org/~pathoschild/stewardry/?wiki="),
                  ("Strategy", "http://strategy.wikimedia.org/wiki/"),
                  ("StrategyWiki", "http://strategywiki.org/wiki/"),
-                 ("Sulutil", "http://toolserver.org/~vvv/sulutil.php?user="),
+                 ("Sulutil", "http://toolserver.org/~quentinv57/sulinfo/"),
                  ("SwinBrain", "http://mercury.it.swin.edu.au/swinbrain/index.php/"),
                  ("SwingWiki", "http://www.swingwiki.org/"),
                  ("Swtrain", "http://train.spottingworld.com/"),
@@ -309,7 +316,6 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("Ticket", "https://ticket.wikimedia.org/otrs/index.pl?Action=AgentTicketZoom&TicketNumber="),
                  ("TmNet", "http://www.technomanifestos.net/?"),
                  ("Tools", "http://toolserver.org/"),
-                 ("Trash!Italia", "http://trashware.linux.it/wiki/"),
                  ("Turismo", "http://www.tejo.org/turismo/"),
                  ("TyvaWiki", "http://www.tyvawiki.org/wiki/"),
                  ("USEJ", "http://www.tejo.org/usej/"),
@@ -320,11 +326,11 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("VKoL", "http://kol.coldfront.net/thekolwiki/index.php/"),
                  ("VLOS", "http://www.thuvienkhoahoc.com/tusach/"),
                  ("ValueWiki", "http://www.valuewiki.com/w/"),
-                 ("Veropedia", "http://en.veropedia.com/a/"),
                  ("Vinismo", "http://vinismo.com/en/"),
                  ("VoIPinfo", "http://www.voip-info.org/wiki/view/"),
                  ("WLUG", "http://www.wlug.org.nz/"),
                  ("WMF", "http://wikimediafoundation.org/wiki/"),
+                 ("WMFblog", "http://blog.wikimedia.org/"),
                  ("Webisodes", "http://www.webisodes.org/"),
                  ("Wiki", "http://c2.com/cgi/wiki?"),
                  ("WikiChristian", "http://www.wikichristian.org/index.php?title="),
@@ -400,15 +406,18 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("infoAnarchy", "http://www.infoanarchy.org/en/"),
                  ("lyricwiki", "http://lyrics.wikia.com/"),
                  ("mailarchive", "http://lists.wikimedia.org/pipermail/"),
+                 ("nostalgia", "http://nostalgia.wikipedia.org/wiki/"),
                  ("psycle", "http://psycle.sourceforge.net/wiki/"),
-                 ("pyrev", "http://svn.wikimedia.org/viewvc/pywikipedia?view=rev&revision="),
+                 ("pyrev", "http://www.mediawiki.org/wiki/Special:Code/pywikipedia/"),
                  ("qcwiki", "http://wiki.quantumchemistry.net/index.php/"),
                  ("rev", "http://www.mediawiki.org/wiki/Special:Code/MediaWiki/"),
                  ("rtfm", "http://s23.org/wiki/"),
+                 ("securewikidc", "https://secure.wikidc.org/"),
                  ("semantic-mw", "http://www.semantic-mediawiki.org/wiki/"),
                  ("silcode", "http://www.sil.org/iso639-3/documentation.asp?id="),
                  ("spcom", "http://spcom.wikimedia.org/wiki/"),
                  ("stable", "http://stable.toolserver.org/"),
+                 ("stats", "http://stats.wikimedia.org/"),
                  ("svn", "http://svn.wikimedia.org/viewvc/mediawiki/?view=log"),
                  ("translatewiki", "http://translatewiki.net/wiki/"),
                  ("tswiki", "http://wiki.toolserver.org/view/"),
@@ -418,19 +427,25 @@ wpInterwikiMap = [ ("AbbeNormal", "http://ourpla.net/cgi/pikie?"),
                  ("wikisophia", "http://wikisophia.org/index.php?title="),
                  ("wmar", "http://www.wikimedia.org.ar/wiki/"),
                  ("wmau", "http://wikimedia.org.au/wiki/"),
-                 ("wmca", "http://wikimedia.ca/index.php/"),
+                 ("wmbe", "http://be.wikimedia.org/wiki/"),
+                 ("wmbr", "http://br.wikimedia.org/wiki/"),
+                 ("wmca", "http://wikimedia.ca/wiki/"),
                  ("wmch", "http://www.wikimedia.ch/"),
                  ("wmcz", "http://meta.wikimedia.org/wiki/Wikimedia_Czech_Republic/"),
+                 ("wmdc", "http://wikimediadc.org/wiki/"),
                  ("wmde", "http://wikimedia.de/wiki/"),
                  ("wmfi", "http://fi.wikimedia.org/wiki/"),
+                 ("wmfr", "http://wikimedia.fr/"),
                  ("wmhk", "http://wikimedia.hk/index.php/"),
                  ("wmhu", "http://wiki.media.hu/wiki/"),
                  ("wmid", "http://www.wikimedia.or.id/wiki/"),
                  ("wmil", "http://www.wikimedia.org.il/"),
-                 ("wmin", "http://wikimedia.in/wiki/"),
+                 ("wmin", "http://wiki.wikimedia.in/"),
                  ("wmit", "http://wikimedia.it/index.php/"),
+                 ("wmmx", "http://mx.wikimedia.org/wiki/"),
                  ("wmnl", "http://nl.wikimedia.org/wiki/"),
                  ("wmno", "http://no.wikimedia.org/wiki/"),
+                 ("wmnyc", "http://nyc.wikimedia.org/wiki/"),
                  ("wmpl", "http://pl.wikimedia.org/wiki/"),
                  ("wmrs", "http://rs.wikimedia.org/wiki/"),
                  ("wmru", "http://ru.wikimedia.org/wiki/"),
